# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.22.6~41dd723',
    built_at='2025-10-21 21:04:44Z',
    sha='41dd723b93f7308a754080ffeb0acc870f00ce81',
    branch='HEAD',
    tag='v4.22.6',
)
